@@ -71,7 +71,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.close.clicked.connect(self.closefunc)
         self.ui.minimize.clicked.connect(self.minimizefunc)
         self.ui.idea.clicked.connect(self.ideafunc)
-        self.ui.about.clicked.connect(self.aboutfunc)
+        self.ui.about.clicked.connect(self.donate)
         self.ui.craveo.clicked.connect(self.craveobrowser)
         self.ui.checkButton.toggled.connect(self.checked)
         self.ui.checkedButton.toggled.connect(self.unchecked)
@@ -85,7 +85,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.checkedButton.hide()
         self.ui.checkButton.show()
         self.ui.checkButton.setChecked(False)
-        self.k
+        
        
     def fartrandom(self):#Zufallsmechanismus für Abspielen der Furzsounds 10-81 
         
@@ -117,8 +117,10 @@ class MainWindow(QtGui.QMainWindow):
     def craveobrowser(self):
         webbrowser.open("http://www.craveo.de")
         
-    def aboutfunc(self):
-        QtGui.QMessageBox.aboutQt(self) 
+    def donate(self):
+	webbrowser.open("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=QFCCCX495Q392")
+        sys.exit()        
+        #QtGui.QMessageBox.aboutQt(self) 
                           
     
 app = QtGui.QApplication(sys.argv)
